@@ -209,7 +209,7 @@ class TorchFitter:
                 break
 
             # Scheduler step after validation
-            if self.validation_scheduler:
+            if self.validation_scheduler and self.scheduler is not None:
                 self.scheduler.step(metrics=calculated_metric)
 
             training_history.append(history)
@@ -257,7 +257,8 @@ class TorchFitter:
 
             self.optimizer.step()
 
-            if self.step_scheduler:
+            # LR Scheduler step after epoch
+            if self.step_scheduler and self.scheduler is not None:
                 self.scheduler.step()
 
         self.log(f'\r[TRAIN] {(time.time() - t):.2f}s - train loss: {summary_loss.avg:.5f}')
